What is this
============

|Build Status| |nbsp| |Latest Release|

The package to simplify a usual work with configuration files from Python programs.

.. TODO More docs and features ;-)

.. |Latest Release| image:: https://badge.fury.io/py/trivial-yaml-config.svg
    :target: https://pypi.org/project/trivial-yaml-config/#history
.. |Build Status| image:: https://travis-ci.org/zaufi/trivial-yaml-config.svg?branch=master
   :target: https://travis-ci.org/zaufi/trivial-yaml-config
.. |nbsp| unicode:: 0xA0
   :trim:
